@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2024 Statnet Commons
+#  Copyright 2003-2025 Statnet Commons
 ################################################################################
 
 #=======================================================================================
@@ -217,7 +217,7 @@ ergm_proposal.character <- function(object, arguments, nw, ..., reference=ergm_r
   prop.call <-
     if((argnames <- names(formals(eval(f))))[1]=="nw"){
       if(! "..."%in%argnames) stop("New-type InitErgmProposal ", sQuote(format(f)), " must have a ... argument.")
-      termCall(f, arguments, nw, term.options, ...)
+      termCall(f, arguments, nw, term.options, reference=reference, ...)
     }else as.call(list(f, arguments, nw))
 
   proposal <- eval(prop.call)
@@ -235,7 +235,8 @@ ergm_proposal.character <- function(object, arguments, nw, ..., reference=ergm_r
 
   # Add the package to the list of those to be loaded.
   ergm.MCMC.packagenames(proposal$pkgname)
-  
+  check_ABI(proposal$pkgname)
+
   class(proposal)<-"ergm_proposal"
   proposal$uid <- .GUID()
   proposal
@@ -281,7 +282,9 @@ ergm_conlist.formula <- function(object, nw, ..., term.options=list())
 
 #' @noRd
 ergm_conlist.term_list <- function(object, nw, ..., term.options=list()){
-  object<-c(object, list(call(".attributes")))
+  object <-
+    if(is(object, "AsIs")) structure(object, class = class(object)[class(object) != "AsIs"])
+    else c(object, list(call(".attributes")))
   consigns <- attr(object, "sign")
   conenvs <- attr(object, "env")
 
@@ -473,7 +476,7 @@ ergm_proposal.ergm_conlist <- function(object, arguments, nw, weights="default",
     name <- proposal$Proposal
     arguments$constraints <- object
     ## Hand it off to the class character method.
-    proposal <- ergm_proposal(name, arguments, nw, reference = reference, ..., term.options = term.options)
+    proposal <- ergm_proposal(name, arguments, nw, reference = reference, weights = weights, class = class, ..., term.options = term.options)
 
     ## Keep trying until some proposal function accepts.
     if(!is.null(proposal) && !is.character(proposal)) break
