@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2024 Statnet Commons
+#  Copyright 2003-2025 Statnet Commons
 ################################################################################
 ## A function to compute and return the log-likelihood of an ERGM MLE.
 
@@ -201,9 +201,8 @@ nobs.ergm <- function(object, ...){
     warning("The number of observed dyads in this network is ill-defined due to complex constraints on the sample space. Disable this warning with ",sQuote("options(ergm.loglik.warn_dyads=FALSE)"),".")
   }
 
-  NVL3(NVL(object$mple.null.lik, object$mple.lik, object$null.lik, object$mle.lik),
-       attr(.,"nobs"),
-       object$info$n_info_dyads)
+  object$info$n_info_dyads %||%
+    attr(NVL(object$mple.null.lik, object$mple.lik, object$null.lik, object$mle.lik), "obs")
 }
 
 NO_NULL_IMPLICATION <- "This means that all likelihood-based inference (LRT, Analysis of Deviance, AIC, BIC, etc.) is only valid between models with the same reference distribution and constraints."
