@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2024 Statnet Commons
+ *  Copyright 2003-2025 Statnet Commons
  */
 #ifndef _ERGM_DYADGEN_H_
 #define _ERGM_DYADGEN_H_
@@ -40,6 +40,7 @@ typedef struct {
     HashEL *hel;
   } inter;
   Rboolean sleeping;
+  Rboolean careless;
 } DyadGen;
 
 void DyadGenSetUpIntersect(DyadGen *gen, void *track_nwp, Rboolean force);
@@ -50,6 +51,11 @@ void DyadGenDestroy(DyadGen *gen);
 void DyadGenUpdate(Vertex tail, Vertex head, void *gen, Network *nwp, Rboolean edgestate);
 void WtDyadGenUpdate(Vertex tail, Vertex head, double weight, void *gen, WtNetwork *nwp, double edgestate);
 
+/* Callback management */
+typedef void (*OnDyadGenInit)(DyadGen *, void *);
+void AddOnDyadGenInit(OnDyadGenInit callback, void *payload);
+void DeleteOnDyadGenInit(OnDyadGenInit callback, void *payload);
+
 static inline void DyadGenRandDyad(Vertex *tail, Vertex *head, DyadGen *gen){
   switch(gen->type){
   case RandDyadGen:
@@ -262,4 +268,9 @@ static inline void DyadGenWake(DyadGen *gen){
   gen->sleeping = FALSE;
 }
 
+
+static inline void DyadGenCareful(DyadGen *gen, Rboolean value){
+  gen->careless = !value;
+}
+
 #endif
