@@ -5,26 +5,29 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2024 Statnet Commons
+ *  Copyright 2003-2025 Statnet Commons
  */
 #include "ergm_etamap.h"
 #include <Rversion.h>
 
-#define SETUP_CALL(fun)                         \
-  SEXP cm = VECTOR_ELT(curved, i);              \
-  SEXP toR = getListElement(cm, "to");          \
-  unsigned int to = INTEGER(toR)[0];            \
-  unsigned int nto = length(toR);               \
-  SEXP fromR = getListElement(cm, "from");      \
-  unsigned int from = INTEGER(fromR)[0];        \
-  unsigned int nfrom = length(fromR);           \
-  SEXP cov = getListElement(cm, "cov");         \
-  SEXP fun = getListElement(cm, #fun);          \
-                                                \
+/* UINT_MAX's are there to segfault as soon as possible if empty from
+   and to vectors are actually used rather than return misleading
+   results. */
+#define SETUP_CALL(fun)                                                 \
+  SEXP cm = VECTOR_ELT(curved, i);                                      \
+  SEXP toR = getListElement(cm, "to");                                  \
+  unsigned int nto = length(toR);                                       \
+  unsigned int to = nto ? INTEGER(toR)[0] : UINT_MAX;                   \
+  SEXP fromR = getListElement(cm, "from");                              \
+  unsigned int nfrom = length(fromR);                                   \
+  unsigned int from = nfrom ? INTEGER(fromR)[0] : UINT_MAX;             \
+  SEXP cov = getListElement(cm, "cov");                                 \
+  SEXP fun = getListElement(cm, #fun);                                  \
+                                                                        \
   SEXP pos = call, arg;                                                 \
   SETCAR(pos, fun); pos = CDR(pos);                                     \
   SETCAR(pos, (arg = allocVector(REALSXP, nfrom))); pos = CDR(pos); /* Don't need to PROTECT the vector this way. */ \
-  memcpy(REAL(arg), theta1+from, nfrom*sizeof(double));                 \
+  if(nfrom) memcpy(REAL(arg), theta1+from, nfrom*sizeof(double));       \
   SETCAR(pos, ScalarInteger(nto)); pos = CDR(pos);                      \
   SETCAR(pos, cov);
 
@@ -121,6 +124,7 @@ void ergm_etagrad(double *theta, SEXP etamap, double *etagrad){
 
     for(unsigned int i = 0; i < ncurved; i++){
       SETUP_CALL(gradient);
+      if(nfrom == 0) continue;
       double *g = REAL(eval(call, R_EmptyEnv));
       double *dest = etagrad1+from+to*ntheta;
       for(unsigned int j=0; j<nto; j++, dest+=ntheta, g+=nfrom)
@@ -178,6 +182,7 @@ void ergm_etagradmult(double *theta, double *v, unsigned int nv, SEXP etamap, do
 
     for(unsigned int i = 0; i < ncurved; i++){
       SETUP_CALL(gradient);
+      if(nfrom == 0) continue;
       double *g = REAL(eval(call, R_EmptyEnv));
       double *g1 = g - 1 - nfrom;
       for(unsigned int j=1; j<=nfrom; j++){
