@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2024 Statnet Commons
+ *  Copyright 2003-2025 Statnet Commons
  */
 #include <string.h>
 #include "ergm_wtmodel.h"
@@ -162,6 +162,7 @@ WtModel* WtModelInitialize (SEXP mR, SEXP ext_state, WtNetwork *nwp, Rboolean no
       the respective functions.*/
       const char *fname = FIRSTCHAR(getListElement(thisterm->R, "name")),
         *sn = FIRSTCHAR(getListElement(thisterm->R, "pkgname"));
+
       /* Extract the required string information from the relevant sources */
       char *fn = R_Calloc(strlen(fname)+3, char);
       fn[1]='_';
@@ -457,9 +458,15 @@ void WtSummStats(Edge n_edges, Vertex *tails, Vertex *heads, double *weights, Wt
     /* The following code is pretty inefficient, but it'll do for now. */
     /* Grab network state and output workspace. */
     n_edges = EDGECOUNT(nwp);
-    tails = R_Calloc(n_edges, Vertex);
-    heads = R_Calloc(n_edges, Vertex);
-    weights = R_Calloc(n_edges, double);
+    /* Use R's memory management to make the routine interruptible.
+
+       TODO: Check how much overhead this incurs over and above
+       in-house on.exit() memory management.
+    */
+    tails = (Vertex *) INTEGER(PROTECT(allocVector(INTSXP, n_edges)));
+    heads = (Vertex *) INTEGER(PROTECT(allocVector(INTSXP, n_edges)));
+    weights = REAL(PROTECT(allocVector(REALSXP, n_edges)));
+
     WtEdgeTree2EdgeList(tails, heads, weights, nwp, n_edges);
     stats = m->workspace;
 
@@ -468,7 +475,12 @@ void WtSummStats(Edge n_edges, Vertex *tails, Vertex *heads, double *weights, Wt
     m = WtModelInitialize(m->R, m->ext_state, nwp, TRUE);
     mynet = TRUE;
   }else{
-    stats = R_Calloc(m->n_stats, double);
+    /* Use R's memory management to make the routine interruptible.
+
+       TODO: Check how much overhead this incurs over and above
+       in-house on.exit() memory management.
+    */
+    stats = REAL(PROTECT(allocVector(REALSXP, m->n_stats)));
     mynet = FALSE;
   }
 
@@ -524,12 +536,10 @@ void WtSummStats(Edge n_edges, Vertex *tails, Vertex *heads, double *weights, Wt
   if(mynet){
     WtModelDestroy(nwp,m);
     WtNetworkDestroy(nwp);
-    R_Free(tails);
-    R_Free(heads);
-    R_Free(weights);
+    UNPROTECT(3);
   }else{
     WtDetUnShuffleEdges(tails,heads,weights,n_edges); /* Unshuffle edgelist. */
     memcpy(m->workspace, stats, m->n_stats*sizeof(double));
-    R_Free(stats);
+    UNPROTECT(1);
   }
 }
